@@ -29,7 +29,6 @@ using CVXOPT in some academic work, consider citing the corresponding report
 [Vandenberghe2010]_.
 """
 
-import warnings
 from typing import Dict, Optional, Union
 
 import cvxopt
@@ -42,6 +41,7 @@ from ..problem import Problem
 from ..solution import Solution
 
 cvxopt.solvers.options["show_progress"] = False  # disable verbose output
+__infty__ = 1e10  # 1e20 tends to yield division-by-zero errors
 
 
 def __to_cvxopt(
@@ -61,7 +61,8 @@ def __to_cvxopt(
         Matrix in CVXOPT format.
     """
     if isinstance(M, np.ndarray):
-        return cvxopt.matrix(M)
+        M_noinf = np.nan_to_num(M, posinf=__infty__, neginf=-__infty__)
+        return cvxopt.matrix(M_noinf)
     coo = M.tocoo()
     return cvxopt.spmatrix(
         coo.data.tolist(), coo.row.tolist(), coo.col.tolist(), size=M.shape
@@ -251,12 +252,6 @@ def cvxopt_solve_qp(
     :
         Primal solution to the QP, if found, otherwise ``None``.
     """
-    warnings.warn(
-        "The return type of this function will change "
-        "to qpsolvers.Solution in qpsolvers v3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = cvxopt_solve_problem(
         problem, solver, initvals, verbose, **kwargs
