@@ -237,12 +237,6 @@ def gurobi_solve_qp(
     the cost of computation time. See *e.g.* [tolerances]_ for a primer of
     solver tolerances.
     """
-    warnings.warn(
-        "The return type of this function will change "
-        "to qpsolvers.Solution in qpsolvers v3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = gurobi_solve_problem(problem, initvals, verbose, **kwargs)
     return solution.x
