@@ -292,12 +292,6 @@ def osqp_solve_qp(
     solutions at the cost of computation time. See *e.g.* [tolerances]_ for an
     overview of solver tolerances.
     """
-    warnings.warn(
-        "The return type of this function will change "
-        "to qpsolvers.Solution in qpsolvers v3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = osqp_solve_problem(problem, initvals, verbose, **kwargs)
     return solution.x
