@@ -37,7 +37,7 @@ import warnings
 from typing import Any, List, Optional, Tuple
 
 import numpy as np
-from numpy import array, hstack, ones, vstack
+from numpy import array, hstack, vstack
 from qpoases import PyOptions as Options
 from qpoases import PyPrintLevel as PrintLevel
 from qpoases import PyQProblem as QProblem
@@ -48,7 +48,8 @@ from ..exceptions import ProblemError
 from ..problem import Problem
 from ..solution import Solution
 
-__infty__ = 1e10
+# See qpOASES/include/Constants.hpp
+__infty__ = 1.0e20
 
 
 # Return codes not wrapped in qpoases.PyReturnValue
@@ -61,6 +62,20 @@ RET_INIT_FAILED_UNBOUNDEDNESS = 38
 RET_INIT_FAILED_REGULARISATION = 39
 
 
+def __clamp_infinities(v: Optional[np.ndarray]):
+    """
+    Replace infinite values in an array by big finite ones.
+
+    Note
+    ----
+    qpOASES requires large bounds instead of infinite float values. See the
+    following issue: https://github.com/coin-or/qpOASES/issues/126
+    """
+    if v is not None:
+        v = np.nan_to_num(v, posinf=__infty__, neginf=-__infty__)
+    return v
+
+
 def __prepare_options(
     verbose: bool,
     predefined_options: Optional[str],
@@ -133,15 +148,18 @@ def __convert_inequalities(
     :
         Tuple ``(C, lb_C, ub_C)`` for qpOASES.
     """
+    C: np.ndarray = np.array([])
     lb_C: Optional[np.ndarray] = None
-    C = np.array([])
+    ub_C: np.ndarray = np.array([])
     if G is not None and h is not None:
+        h_neginf = np.full(h.shape, -__infty__)
         if A is not None and b is not None:
             C = vstack([G, A])
-            lb_C = hstack([-__infty__ * ones(h.shape[0]), b])
+            lb_C = hstack([h_neginf, b])
             ub_C = hstack([h, b])
         else:  # no equality constraint
             C = G
+            lb_C = h_neginf
             ub_C = h
     else:  # no inequality constraint
         if A is not None and b is not None:
@@ -231,16 +249,24 @@ def qpoases_solve_problem(
     if initvals is not None:
         print("qpOASES: note that warm-start values ignored by wrapper")
     P, q, G, h, A, b, lb, ub = problem.unpack()
+
     n = P.shape[0]
+    lb = np.full((n,), -np.inf) if lb is None else lb
+    ub = np.full((n,), +np.inf) if ub is None else ub
     C, lb_C, ub_C = __convert_inequalities(G, h, A, b)
+    lb_C = __clamp_infinities(lb_C)
+    ub_C = __clamp_infinities(ub_C)
+    lb = __clamp_infinities(lb)
+    ub = __clamp_infinities(ub)
 
     args: List[Any] = []
+    n_wsr = np.array([max_wsr])
     if C.shape[0] > 0:
         qp = QProblem(n, C.shape[0])
-        args = [P, q, C, lb, ub, lb_C, ub_C, array([max_wsr])]
+        args = [P, q, C, lb, ub, lb_C, ub_C, n_wsr]
     else:  # at most box constraints
         qp = QProblemB(n)
-        args = [P, q, lb, ub, array([max_wsr])]
+        args = [P, q, lb, ub, n_wsr]
     if time_limit is not None:
         args.append(array([time_limit]))
 
@@ -258,6 +284,7 @@ def qpoases_solve_problem(
     if return_value == ReturnValue.MAX_NWSR_REACHED:
         warnings.warn(f"qpOASES reached the maximum number of WSR ({max_wsr})")
         return solution
+
     x_opt = np.empty((n,))
     z_opt = np.empty((n + C.shape[0],))
     qp.getPrimalSolution(x_opt)  # can't return RET_QP_NOT_SOLVED at this point
@@ -271,6 +298,9 @@ def qpoases_solve_problem(
     if A is not None:
         solution.y = -z_opt[n + m : n + m + A.shape[0]]
     solution.obj = qp.getObjVal()
+    solution.extras = {
+        "nWSR": n_wsr[0],
+    }
     return solution
 
 
@@ -384,12 +414,6 @@ def qpoases_solve_qp(
     <https://www.coin-or.org/qpOASES/doc/3.1/manual.pdf>`_. for all available
     options.
     """
-    warnings.warn(
-        "The return type of this function will change "
-        "to qpsolvers.Solution in qpsolvers v3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = qpoases_solve_problem(
         problem,
