@@ -237,12 +237,6 @@ def quadprog_solve_qp(
     :
         Primal solution to the QP, if found, otherwise ``None``.
     """
-    warnings.warn(
-        "The return type of this function will change "
-        "to qpsolvers.Solution in qpsolvers v3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = quadprog_solve_problem(problem, initvals, verbose, **kwargs)
     return solution.x
