@@ -54,6 +54,5 @@ try:
             self.assertIsNotNone(x)
 
 
-except ImportError:  # HiGHS not installed
-
-    pass
+except ImportError:  # solver not installed
+    warnings.warn("Skipping HiGHS tests as the solver is not installed")
